@@ -12,20 +12,20 @@ use super::pitch_sign::PitchSignDsl;
 
 pub struct NoteDsl {
     pub octave_tweak: Option<OctaveTweakDsl>,
-    pub pitch_sign: PitchSignDsl,
     pub pitch_name: PitchNameDsl,
+    pub pitch_sign: PitchSignDsl,
 }
 
 impl Parse for NoteDsl {
     #[throws(Error)]
     fn parse(input: ParseStream) -> Self {
         let octave_tweak = OctaveTweakDsl::try_parse(input);
-        let pitch_sign = input.parse::<PitchSignDsl>()?;
         let pitch_name = input.parse::<PitchNameDsl>()?;
+        let pitch_sign = input.parse::<PitchSignDsl>()?;
         NoteDsl {
             octave_tweak,
-            pitch_sign,
             pitch_name,
+            pitch_sign,
         }
     }
 }
@@ -40,8 +40,8 @@ impl ToTokens for NoteDsl {
     fn to_tokens(&self, tokens: &mut TokenStream) {
         let NoteDsl {
             octave_tweak,
-            pitch_sign,
             pitch_name,
+            pitch_sign,
         } = self;
         if pitch_name.from_syllable {
             let syllable = Syllable::from((pitch_sign.sign, pitch_name.name));
@@ -69,7 +69,7 @@ impl NoteDsl {
             let syllable = Syllable::from((pitch_sign.sign, pitch_name.name));
             Context::calc_note(octave_tweak, &syllable)
         } else {
-            let octave = Context::octave(octave_tweak);
+            let octave = Context::tweaked_octave(octave_tweak);
             let pitch = Pitch::new(pitch_name.name, pitch_sign.sign);
             Note::new(octave, pitch)
         }
